import { MotionProps, useInView } from 'framer-motion';
import { useMemo } from 'react';

interface GetFadeInEffect {
  delay?: number;
  duration?: number;
  direction?: 'top' | 'bottom' | 'right' | 'left' | 'no';
  amount: number;
}

// 컨테이너의 자식들이 차례대로 아래에서 위로
export const getFadeInEffect = (props?: GetFadeInEffect): MotionProps => {
  const { delay = 0.2, duration = 0.5, direction = 'bottom', amount = 50 } = props || {};

  const initial = 'hidden';
  const whileInView = 'show';
  const { initialX, initialY } = getInitialXY(direction, amount);

  return {
    initial,
    whileInView,
    variants: {
      [initial]: { opacity: 0, x: initialX, y: initialY },
      [whileInView]: { opacity: 1, x: 0, y: 0 },
    } as any,
    transition: {
      delay,
      duration,
    },
    viewport: { once: true },
  } as any;
};

function getInitialXY(direction: GetFadeInEffect['direction'], amount: GetFadeInEffect['amount']) {
  const initialX = direction === 'left' ? amount : direction === 'right' ? -amount : 0;
  const initialY = direction === 'top' ? amount : direction === 'bottom' ? -amount : 0;

  return { initialX, initialY };
}
