import styled from 'styled-components';
import { motion } from 'framer-motion';
import theme from '../../../../theme';
import { Stack } from '../../../layout';

export interface CheckBoxInputProps {
  isActive?: boolean;
  defaultColor?: string;
  activeColor?: string;
  label?: { color?: string; text?: string };
}

const CheckIcon = (props: any) => {
  return (
    <svg xmlns="http://www.w3.org/2000/svg" width="14" height="11" {...props}>
      <path d="M 12.333 1.692 L 5 9.308 L 1.667 5.846" fill="transparent" strokeWidth="2" stroke="hsl(0, 0%, 100%)" strokeLinecap="round" strokeLinejoin="round"></path>
    </svg>
  );
};

export default function CheckBoxInput(props: CheckBoxInputProps) {
  const { isActive, label, defaultColor, activeColor } = props;

  return (
    <Box>
      <Stack gap={8}>
        <CheckBoxIcon isActive={isActive} defaultColor={defaultColor} activeColor={activeColor}>
          {isActive && <CheckIconStyled color={theme.colors.white} />}
        </CheckBoxIcon>
        {label.text && (
          <LabelStyled isActive={isActive} defaultColor={defaultColor} activeColor={activeColor}>
            {label.text}
          </LabelStyled>
        )}
      </Stack>
      <VisuallyHiddenRadio type="checkbox" checked={isActive} />
    </Box>
  );
}

CheckBoxInput.defaultProps = {
  isActive: true,
  defaultColor: theme.colors.gray300,
  activeColor: theme.colors.black,
  label: {
    text: 'Check',
  },
};

const Box = styled(motion.div)`
  display: flex;
  position: relative;
  font-family: ${theme.fontFamily.normal};
`;

const CheckIconStyled = styled(CheckIcon)<CheckBoxInputProps>`
  position: absolute;
  top: 50%;
  left: 50%;
  transform: translate(-50%, -50%);
`;

const CheckBoxIcon = styled(motion.div)<CheckBoxInputProps>`
  width: 24px;
  height: 24px;
  position: relative;
  border: 2px solid ${({ isActive, activeColor, defaultColor }) => (isActive ? 'none' : defaultColor)};
  background: ${({ isActive, activeColor, defaultColor }) => (isActive ? activeColor : 'none')};
  border-radius: 6px;
`;

const LabelStyled = styled(motion.label)<CheckBoxInputProps>`
  font-size: 16px;
  line-height: 1.5;
  letter-spacing: -0.3px;
  color: ${({ isActive, activeColor, defaultColor }) => (isActive ? activeColor : defaultColor)};
  font-family: ${({ isActive }) => (isActive ? theme.fontFamily.bold : theme.fontFamily.normal)};
`;

const VisuallyHiddenRadio = styled.input`
  position: absolute;
  width: 1px;
  height: 1px;
  padding: 0;
  margin: -1px;
  overflow: hidden;
  clip: rect(0, 0, 0, 0);
  white-space: nowrap;
  border: 0;
`;
