import styled from 'styled-components';
import Icon, { iconNames, IconNames } from '../../atoms/Icon';
import theme from '../../../../theme';

export interface IconButtonProps {
  icon?: IconNames;
  iconSize?: number;
  color?: string;
  backgroundColor?: string;
  borderRadius?: string;
  onClick?: any;
  opacity?: number;
}

export default function IconButton(props: IconButtonProps) {
  const { icon, iconSize, color, onClick, ...remain } = props;

  return (
    <IconButtonStyled onClick={onClick} {...props}>
      <Icon name={icon} size={iconSize} color={color} />
    </IconButtonStyled>
  );
}

IconButton.defaultProps = {
  iconSize: 24,
  color: theme.colors.black,
  backgroundColor: 'transparent',
  borderRadius: '50%',
  icon: 'home',
  opacity: 1,
  onClick: () => console.log('아이콘 버튼 클릭됨'),
};

const IconButtonStyled = styled.button<IconButtonProps>`
  display: flex;
  justify-content: center;
  align-items: center;
  color: ${props => props.color};
  background-color: ${props => props.backgroundColor};
  border-radius: ${props => props.borderRadius};
  border-color: transparent;
  opacity: ${props => props.opacity};
  borer-width: 0px;
  cursor: pointer;
  padding: 0;
  &:hover {
    opacity: 0.85;
  }
`;
