import styled from 'styled-components';
import { motion } from 'framer-motion';
import { produce } from 'immer';
import theme from '../../../../theme';
import Paragraph, { ParagraphProps } from '../../atoms/Paragraph/Paragraph';
import Button, { ButtonProps } from '../../molecules/Button/Button';
import Title from '../../atoms/Title/Title';

export interface Card1Props {
  logoUrl?: string;
  title?: ParagraphProps;
  description?: ParagraphProps;
  name?: ParagraphProps;
  company?: ParagraphProps;
  isMobile?: boolean;
  backgroundColor?: string;
  buttonProps?: ButtonProps;
}

export default function Card1(props: Card1Props) {
  const { backgroundColor, logoUrl, title, description, name, company, buttonProps, isMobile } = props;

  return (
    <Box backgroundColor={backgroundColor} isMobile={isMobile}>
      <Logo isMobile={isMobile} src={logoUrl} />
      <Paragraph margin={isMobile ? '16px 0 0' : '32px 0 0'} {...title} isMobile={isMobile} />
      <Paragraph margin="4px 0 0" {...description} isMobile={isMobile} />
      <Paragraph margin={isMobile ? '35px 0 0' : '51px 0 0'} {...name} isMobile={isMobile} />
      <Paragraph {...company} isMobile={isMobile} />
      <Button size={isMobile ? 'sm' : 'md'} margin="16px 0 0" {...buttonProps} />
    </Box>
  );
}

Card1.defaultProps = {
  logoUrl: 'https://codeindesign.s3.ap-northeast-2.amazonaws.com/CodeInDesign+Logo.png',
  title: produce(Title.defaultProps, draft => {
    draft.fontWeight = 'bold';
    draft.size = 'md';
    draft.color = theme.colors.gray500;
    draft.content = '이곳은 제목이 들어가는 영역입니다\n개행처리도 아주 잘 됩니다';
  }),
  description: produce(Title.defaultProps, draft => {
    draft.fontWeight = 'bold';
    draft.size = 'md';
    draft.color = theme.colors.gray500;
    draft.content = '비즈니스 PT 받은 느낌이에요!비즈니스 PT 받은 느낌이에요!';
  }),
  name: produce(Title.defaultProps, draft => {
    draft.size = 'lg';
    draft.content = '심재철';
  }),
  company: produce(Title.defaultProps, draft => {
    draft.size = 'md';
    draft.content = '코드인디자인 대표';
  }),
  isMobile: false,
  backgroundColor: theme.colors.gray50,
  buttonProps: produce(Button.defaultProps, draft => {
    draft.backgroundColor = theme.colors.white;
    draft.icon = 'chevron-right';
    draft.iconPosition = 'right';
    draft.color = theme.colors.gray500;
    draft.content = '포트폴리오 보러가기';
    draft.border.color = theme.colors.gray500;
    draft.border.width = 1;
  }),
};

const Box = styled(motion.div)<any>`
  background-color: ${props => props.backgroundColor};
  padding: ${props => (props.isMobile ? '20px' : '40px')};
  width: 100%;
  max-width: ${props => (props.isMobile ? '246px' : '367px')};
  margin: 0 auto;
  border-radius: 20px;
`;
const Logo = styled(motion.img)<any>`
  width: ${props => (props.isMobile ? '100px' : '128px')};
  height: ${props => (props.isMobile ? '50px' : '64px')};
  object-fit: contain;
`;
