import styled from 'styled-components';
import { motion } from 'framer-motion';
import { produce } from 'immer';
import theme from '../../../../theme';
import { Container, Stack } from '../../../layout';
import Paragraph, { ParagraphProps } from '../../atoms/Paragraph/Paragraph';
import Title, { TitleProps } from '../../atoms/Title/Title';
import Button, { ButtonProps } from '../../molecules/Button/Button';

export interface CtaSection1Props {
  subTitle: TitleProps;
  title: TitleProps;
  description: ParagraphProps;
  buttons: ButtonProps[];
  backgroundImage?: string;
  backgroundColor?: string;
  isMobile?: boolean;
}

export default function CtaSection1(props: CtaSection1Props) {
  const { subTitle, title, description, buttons, backgroundImage, backgroundColor, isMobile } = props;

  return (
    <Container isMobile={isMobile} backgroundImage={backgroundImage} backgroundColor={backgroundColor}>
      <ContentBox isMobile={isMobile}>
        <Title {...subTitle} isMobile={isMobile} />
        <Title {...title} isMobile={isMobile} margin={isMobile ? '4px 0 0' : '8px 0 0'} />
        <Paragraph {...description} isMobile={isMobile} margin={isMobile ? '12px 0 0' : '16px 0 0'} />
        <Stack gap={isMobile ? 12 : 20} justifyContent="center" margin={isMobile ? '24px 0 0' : '40px 0 0'}>
          {buttons.map((button, index) => {
            return <Button {...button} key={index} />;
          })}
        </Stack>
      </ContentBox>
    </Container>
  );
}

CtaSection1.defaultProps = {
  subTitle: produce(Title.defaultProps, draft => {
    draft.content = '이것은 서브타이틀입니다';
    draft.size = 'sm';
    draft.fontWeight = 'normal';
    draft.textAlign = 'center';
  }),
  title: produce(Title.defaultProps, draft => {
    draft.content = '코드인디자인\n코드인디자인 코드인디자인';
    draft.size = 'lg';
    draft.highlight.color = theme.colors.gray500;
    draft.highlight.height = 36;
    draft.highlight.isVisible = true;
    draft.textAlign = 'center';
  }),
  description: produce(Paragraph.defaultProps, draft => {
    draft.content = 'Body 입력 Body 입력 무엇을 구하지 꽃이 무엇이 천고에 천자만홍이 황금시대다.\n피는 대한 따뜻한 꽃 가슴이 봄바람이다. 속에서 밥을 끓는 속잎나고.';
    draft.textAlign = 'center';
  }),
  buttons: Array(2).fill(Button.defaultProps),
  backgroundImage: 'https://picsum.photos/id/10/1200',
  backgroundColor: 'transparent',
  isMobile: false,
};

const ContentBox = styled(motion.div)<any>`
  display: flex;
  flex-direction: column;
  width: 100%;
`;
