import { ReactNode, HTMLProps } from 'react';
import styled from 'styled-components';
import { motion } from 'framer-motion';
import theme from '../../../theme';

interface ContainerProps {
  direction?: 'row' | 'column';
  isMobile?: boolean;
  isCenter?: boolean;
  backgroundColor?: string;
  backgroundImage?: string;
  children?: ReactNode;
  padding?: string;
}

/** Contaiener 컴포넌트는 컨텐츠의 최대 가로폭을 지정하는 역할을 합니다. */
export default function Container(props: ContainerProps) {
  const { children, padding, ...remain } = props;

  return (
    <Box padding={padding} {...remain}>
      <ContentBox {...remain}>{children}</ContentBox>
    </Box>
  );
}

Container.defaultProps = {
  direction: 'row',
  isMobile: false,
  isCenter: false,
  backgroundColor: 'transparent',
};

const Box = styled(motion.div)<any>`
  display: flex;
  width: 100%;
  margin: 0 auto;
  box-sizing: boder-box;
  padding: ${props => (props.padding ? props.padding : props.isMobile ? '80px 0' : '120px 0')};
  background-color: ${props => props.backgroundColor};
  background-image: url(${props => props.backgroundImage});
  background-size: cover;

  ${props =>
    props.isMobile &&
    `
        padding-left: 16px;
        padding-right: 16px;
    `};
`;

const ContentBox = styled(motion.div)<any>`
  display: flex;
  width: 100%;
  flex-direction: ${props => props.direction};
  max-width: 1056px;
  margin: 0 auto;
  ${props =>
    props.isCenter &&
    `
        justify-content: center;
        align-items: center;
    `};
`;
