import rgba from 'color-rgba';

class ColorUtil {
  /**
   * 주어진 텍스트에서 컬러 코드를 해당하는 스타일로 대체합니다.
   *
   * @param text - 컬러 태그가 포함된 원래의 문자열
   * (예: "안녕하세요<c1>첫번째 컬러로 텍스트 감싸기</c1> <c2>두번째 컬러로 텍스트 감싸기</c2>")
   * @param colorCodes - 컬러 코드 배열
   * (예: ["red", "blue"])
   * @returns 대체된 텍스트
   * (예: "안녕하세요<span style="color: red;">첫번째 컬러로 텍스트 감싸기</span> ... 생략")
   */
  applyColorsToText(text, colorCodes) {
    const regularExpression = /<c(\d)>(.*?)<\/c\1>/g;
    const matchFunction = (match, group1, group2) => {
      const colorIndex = parseInt(group1) - 1;
      const color = colorCodes[colorIndex];

      if (color) {
        return `<span style="color: ${color};">${group2}</span>`;
      } else {
        return group2;
      }
    };
    const replacedText = text.replace(regularExpression, matchFunction);
    return replacedText;
  }

  /**
   * 주어진 컬러 코드를 RGBA 형식으로 변환하여 반환합니다.
   *
   * @param {string} colorCode - 변환할 컬러 코드 (예: '#FF0000')
   * @param {number} opacity - 투명도 값 (0부터 1 사이의 숫자)
   * @returns {string} - RGBA 형식의 컬러 코드 (예: 'rgba(255, 0, 0, 0.5)')
   */
  convertColorToRGBA = (colorCode, opacity) => {
    const rgbaValue = rgba(colorCode);
    const rgbaWithOpacity = rgbaValue.replace(')', `, ${opacity})`);
    return rgbaWithOpacity;
  };
}

export const colorUtil = new ColorUtil();
